import json

def llm_response_formatter(response, llm_provider, logger):
    """ Extract message content and send to Agents
    Args:
        response: llm provider response
        llm_provider: llm provider name
    Raises:
        ValueError: when llm provider not matched
    Returns: message content as response
    """
    try:
        logger.info('formatting llm response....')
        
        # Handle tuple response
        if isinstance(response, tuple):
            logger.info('llm tuple response formatting...')
            response = response[0]

        # parse the response if it's a JSON string
        if isinstance(response, str):
            logger.info('llm json string response formatting...')
            response = json.loads(response)

        logger.info('extracting message content from llm response....')
        
        # Extract response based on llm provider
        if llm_provider == 'cortex':
            # Add explicit validation for Cortex response structure
            if 'choices' not in response or not response['choices']:
                raise ValueError(f"Invalid response format from llm provider {llm_provider}, response: {response}")
            response = response['choices'][0]['messages'].strip()
        elif llm_provider == 'anthropic':
            response = response.content[0].text.strip()
        elif llm_provider == 'openai':
            response = response.choices[0].message.content.strip()
        else:
            raise KeyError(f"Unsupported llm provider: {llm_provider}")

        logger.info(f'formatted response: {response}')
        return response
    except Exception as e:
        logger.error(f"Error while formatting llm response {llm_provider}: {e}")
        raise